[![Build Status](https://travis-ci.org/troup-system/troup.svg?branch=master)](https://travis-ci.org/troup-system/troup)


Take control of your home grid.

* run applications across multiple computers and platforms transparently, just as you would from your terminal. The application will run on the most appropriate node, determined by algorithm.
* run tasks (run code fragments or processes) transparently across the system. The tasks can be either automatically assigned to a node, similar as the applications; or they can be assigned explicitly to a node.

Installation
============

Install it with pip:

```bash

pip install troup

```


Requirements
============
* psutil
* ws4py

Get started
===========

Check out the the [Getting Started](https://github.com/troup-system/troup/wiki/GettingStarted) guide on the wiki.

Documentation
=============
Read the full documentation [here](http://troup.readthedocs.io/en/latest/).


License
=======

Licensed under the Apache License, Version 2.0.

See the file LICENSE or you may obtain a copy at:
   http://www.apache.org/licenses/LICENSE-2.0
